#[repr(C)]pub struct CStringView {
pub string: *const c_char,
pub length: u32,
}Expand description
This is called rr_string in the C API.
NOTE: CStringView is NOT an Option, and there is no difference between null and “”.
Fields
string: *const c_charlength: u32Implementations
Sourceimpl CStringView
impl CStringView
Sourcepub fn as_maybe_empty_str<'a>(
&'a self,
argument_name: &'a str,
) -> Result<&'a str, CError>
pub fn as_maybe_empty_str<'a>( &'a self, argument_name: &'a str, ) -> Result<&'a str, CError>
Error if the string is not valid UTF8, or is null and non-zero in length.
May return the empty string.
Sourcepub fn as_optional_str<'a>(
&'a self,
argument_name: &'a str,
) -> Result<Option<&'a str>, CError>
pub fn as_optional_str<'a>( &'a self, argument_name: &'a str, ) -> Result<Option<&'a str>, CError>
Treat the empty string “” as None.
Sourcepub fn as_nonempty_str<'a>(
&'a self,
argument_name: &'a str,
) -> Result<&'a str, CError>
pub fn as_nonempty_str<'a>( &'a self, argument_name: &'a str, ) -> Result<&'a str, CError>
Error if the string was empty.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Is this the “” string?
NOTE: CStringView is NOT an Option, and there is no difference between null and “”.